# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class AddPipeRiskWeightInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'weight_factor_name': 'str',
        'weight': 'float',
        'pipe_field': 'str'
    }

    attribute_map = {
        'weight_factor_name': 'weightFactorName',
        'weight': 'weight',
        'pipe_field': 'pipeField'
    }

    def __init__(self, weight_factor_name=None, weight=None, pipe_field=None, local_vars_configuration=None):  # noqa: E501
        """AddPipeRiskWeightInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._weight_factor_name = None
        self._weight = None
        self._pipe_field = None
        self.discriminator = None

        self.weight_factor_name = weight_factor_name
        if weight is not None:
            self.weight = weight
        self.pipe_field = pipe_field

    @property
    def weight_factor_name(self):
        """Gets the weight_factor_name of this AddPipeRiskWeightInput.  # noqa: E501

        参数名  # noqa: E501

        :return: The weight_factor_name of this AddPipeRiskWeightInput.  # noqa: E501
        :rtype: str
        """
        return self._weight_factor_name

    @weight_factor_name.setter
    def weight_factor_name(self, weight_factor_name):
        """Sets the weight_factor_name of this AddPipeRiskWeightInput.

        参数名  # noqa: E501

        :param weight_factor_name: The weight_factor_name of this AddPipeRiskWeightInput.  # noqa: E501
        :type: str
        """

        self._weight_factor_name = weight_factor_name

    @property
    def weight(self):
        """Gets the weight of this AddPipeRiskWeightInput.  # noqa: E501

        权重  # noqa: E501

        :return: The weight of this AddPipeRiskWeightInput.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this AddPipeRiskWeightInput.

        权重  # noqa: E501

        :param weight: The weight of this AddPipeRiskWeightInput.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def pipe_field(self):
        """Gets the pipe_field of this AddPipeRiskWeightInput.  # noqa: E501

        对应管道属性表的字段  # noqa: E501

        :return: The pipe_field of this AddPipeRiskWeightInput.  # noqa: E501
        :rtype: str
        """
        return self._pipe_field

    @pipe_field.setter
    def pipe_field(self, pipe_field):
        """Sets the pipe_field of this AddPipeRiskWeightInput.

        对应管道属性表的字段  # noqa: E501

        :param pipe_field: The pipe_field of this AddPipeRiskWeightInput.  # noqa: E501
        :type: str
        """

        self._pipe_field = pipe_field

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddPipeRiskWeightInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddPipeRiskWeightInput):
            return True

        return self.to_dict() != other.to_dict()
