# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class AccuracyConfigDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'type_name': 'str',
        'threshold': 'float',
        'unit': 'str',
        'description': 'str',
        'remark': 'str',
        'id': 'str'
    }

    attribute_map = {
        'type': 'type',
        'type_name': 'typeName',
        'threshold': 'threshold',
        'unit': 'unit',
        'description': 'description',
        'remark': 'remark',
        'id': 'id'
    }

    def __init__(self, type=None, type_name=None, threshold=None, unit=None, description=None, remark=None, id=None, local_vars_configuration=None):  # noqa: E501
        """AccuracyConfigDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._type_name = None
        self._threshold = None
        self._unit = None
        self._description = None
        self._remark = None
        self._id = None
        self.discriminator = None

        self.type = type
        self.type_name = type_name
        if threshold is not None:
            self.threshold = threshold
        self.unit = unit
        self.description = description
        self.remark = remark
        if id is not None:
            self.id = id

    @property
    def type(self):
        """Gets the type of this AccuracyConfigDto.  # noqa: E501

        精度类型  # noqa: E501

        :return: The type of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AccuracyConfigDto.

        精度类型  # noqa: E501

        :param type: The type of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def type_name(self):
        """Gets the type_name of this AccuracyConfigDto.  # noqa: E501

        精度类型-中文显示  # noqa: E501

        :return: The type_name of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._type_name

    @type_name.setter
    def type_name(self, type_name):
        """Sets the type_name of this AccuracyConfigDto.

        精度类型-中文显示  # noqa: E501

        :param type_name: The type_name of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._type_name = type_name

    @property
    def threshold(self):
        """Gets the threshold of this AccuracyConfigDto.  # noqa: E501

        阈值  # noqa: E501

        :return: The threshold of this AccuracyConfigDto.  # noqa: E501
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this AccuracyConfigDto.

        阈值  # noqa: E501

        :param threshold: The threshold of this AccuracyConfigDto.  # noqa: E501
        :type: float
        """

        self._threshold = threshold

    @property
    def unit(self):
        """Gets the unit of this AccuracyConfigDto.  # noqa: E501

        单位  # noqa: E501

        :return: The unit of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this AccuracyConfigDto.

        单位  # noqa: E501

        :param unit: The unit of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def description(self):
        """Gets the description of this AccuracyConfigDto.  # noqa: E501

        描述  # noqa: E501

        :return: The description of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AccuracyConfigDto.

        描述  # noqa: E501

        :param description: The description of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def remark(self):
        """Gets the remark of this AccuracyConfigDto.  # noqa: E501

        备注  # noqa: E501

        :return: The remark of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this AccuracyConfigDto.

        备注  # noqa: E501

        :param remark: The remark of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def id(self):
        """Gets the id of this AccuracyConfigDto.  # noqa: E501


        :return: The id of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AccuracyConfigDto.


        :param id: The id of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccuracyConfigDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccuracyConfigDto):
            return True

        return self.to_dict() != other.to_dict()
