# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class GetAccuracyPara(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'data_types': 'list[int]',
        'b_force_refresh_cache': 'bool'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'data_types': 'dataTypes',
        'b_force_refresh_cache': 'bForceRefreshCache'
    }

    def __init__(self, scenario_id=None, data_types=None, b_force_refresh_cache=None, local_vars_configuration=None):  # noqa: E501
        """GetAccuracyPara - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._data_types = None
        self._b_force_refresh_cache = None
        self.discriminator = None

        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.data_types = data_types
        if b_force_refresh_cache is not None:
            self.b_force_refresh_cache = b_force_refresh_cache

    @property
    def scenario_id(self):
        """Gets the scenario_id of this GetAccuracyPara.  # noqa: E501

        方案id  # noqa: E501

        :return: The scenario_id of this GetAccuracyPara.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this GetAccuracyPara.

        方案id  # noqa: E501

        :param scenario_id: The scenario_id of this GetAccuracyPara.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def data_types(self):
        """Gets the data_types of this GetAccuracyPara.  # noqa: E501

        数据类型  # noqa: E501

        :return: The data_types of this GetAccuracyPara.  # noqa: E501
        :rtype: list[int]
        """
        return self._data_types

    @data_types.setter
    def data_types(self, data_types):
        """Sets the data_types of this GetAccuracyPara.

        数据类型  # noqa: E501

        :param data_types: The data_types of this GetAccuracyPara.  # noqa: E501
        :type: list[int]
        """
        allowed_values = [None,0, 1, 2, 3, 4, 5, 6, 7, 8, 9]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(data_types).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `data_types` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(data_types) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._data_types = data_types

    @property
    def b_force_refresh_cache(self):
        """Gets the b_force_refresh_cache of this GetAccuracyPara.  # noqa: E501

        是否强制刷新缓存  # noqa: E501

        :return: The b_force_refresh_cache of this GetAccuracyPara.  # noqa: E501
        :rtype: bool
        """
        return self._b_force_refresh_cache

    @b_force_refresh_cache.setter
    def b_force_refresh_cache(self, b_force_refresh_cache):
        """Sets the b_force_refresh_cache of this GetAccuracyPara.

        是否强制刷新缓存  # noqa: E501

        :param b_force_refresh_cache: The b_force_refresh_cache of this GetAccuracyPara.  # noqa: E501
        :type: bool
        """

        self._b_force_refresh_cache = b_force_refresh_cache

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAccuracyPara):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetAccuracyPara):
            return True

        return self.to_dict() != other.to_dict()
