# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class GetFilterModelResultInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'data_type': 'SysWdDataTypeEnum',
        'time': 'datetime',
        'filter_conditions': 'FilterConditionEnum',
        'condition_value': 'list[float]'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'data_type': 'dataType',
        'time': 'time',
        'filter_conditions': 'filterConditions',
        'condition_value': 'conditionValue'
    }

    def __init__(self, scenario_id=None, data_type=None, time=None, filter_conditions=None, condition_value=None, local_vars_configuration=None):  # noqa: E501
        """GetFilterModelResultInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._data_type = None
        self._time = None
        self._filter_conditions = None
        self._condition_value = None
        self.discriminator = None

        self.scenario_id = scenario_id
        if data_type is not None:
            self.data_type = data_type
        if time is not None:
            self.time = time
        if filter_conditions is not None:
            self.filter_conditions = filter_conditions
        self.condition_value = condition_value

    @property
    def scenario_id(self):
        """Gets the scenario_id of this GetFilterModelResultInput.  # noqa: E501


        :return: The scenario_id of this GetFilterModelResultInput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this GetFilterModelResultInput.


        :param scenario_id: The scenario_id of this GetFilterModelResultInput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def data_type(self):
        """Gets the data_type of this GetFilterModelResultInput.  # noqa: E501


        :return: The data_type of this GetFilterModelResultInput.  # noqa: E501
        :rtype: SysWdDataTypeEnum
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this GetFilterModelResultInput.


        :param data_type: The data_type of this GetFilterModelResultInput.  # noqa: E501
        :type: SysWdDataTypeEnum
        """

        self._data_type = data_type

    @property
    def time(self):
        """Gets the time of this GetFilterModelResultInput.  # noqa: E501


        :return: The time of this GetFilterModelResultInput.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this GetFilterModelResultInput.


        :param time: The time of this GetFilterModelResultInput.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def filter_conditions(self):
        """Gets the filter_conditions of this GetFilterModelResultInput.  # noqa: E501


        :return: The filter_conditions of this GetFilterModelResultInput.  # noqa: E501
        :rtype: FilterConditionEnum
        """
        return self._filter_conditions

    @filter_conditions.setter
    def filter_conditions(self, filter_conditions):
        """Sets the filter_conditions of this GetFilterModelResultInput.


        :param filter_conditions: The filter_conditions of this GetFilterModelResultInput.  # noqa: E501
        :type: FilterConditionEnum
        """

        self._filter_conditions = filter_conditions

    @property
    def condition_value(self):
        """Gets the condition_value of this GetFilterModelResultInput.  # noqa: E501


        :return: The condition_value of this GetFilterModelResultInput.  # noqa: E501
        :rtype: list[float]
        """
        return self._condition_value

    @condition_value.setter
    def condition_value(self, condition_value):
        """Sets the condition_value of this GetFilterModelResultInput.


        :param condition_value: The condition_value of this GetFilterModelResultInput.  # noqa: E501
        :type: list[float]
        """

        self._condition_value = condition_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetFilterModelResultInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetFilterModelResultInput):
            return True

        return self.to_dict() != other.to_dict()
